@@ -1,7 +1,7 @@
 package App::ZodiacUtils;
 
-our $DATE = '2016-01-18'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2016-06-02'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,6 +9,14 @@ use warnings;
 
 our %SPEC;
 
+my $sch_array_of_dates = ['array*', {
+    of=>['date*', {
+        'x.perl.coerce_to' => 'DateTime',
+        'x.perl.coerce_rules'=>['str_alami_en'],
+    }],
+    min_len=>1,
+}];
+
 $SPEC{zodiac_of} = {
     v => 1.1,
     summary => 'Show zodiac for a date',
@@ -16,9 +24,7 @@ $SPEC{zodiac_of} = {
         dates => {
             summary => 'Dates',
             'x.name.is_plural' => 1,
-            #schema => ['array*', of=>'date*', min_len=>1],
-            schema => ['array*', of=>'str*', min_len=>1],
-            #'x.perl.coerce_to' => 'int(epoch)',
+            schema => $sch_array_of_dates,
             req => 1,
             pos => 0,
             greedy => 1,
@@ -29,7 +35,6 @@ $SPEC{zodiac_of} = {
         {
             args => {dates=>['2015-06-15']},
             result => 'gemini',
-            test => 0, # at the time of this writing, Test::Rinci hasn't used Perinci::Sub::CoerceArgs
         },
         {
             summary => 'Multiple dates',
@@ -41,7 +46,6 @@ differentiate which zodiac belongs to which date.
 _
             args => {dates=>['2015-12-17','2015-12-29']},
             result => [["2015-12-17","sagittarius"], ["2015-12-29","capricornus"]],
-            test => 0,
         }
     ],
 };
@@ -53,12 +57,16 @@ sub zodiac_of {
 
     my $res = [];
     for my $date (@$dates) {
-        unless ($date =~ /\A\d\d\d\d-\d\d-\d\d\z/) {
-            warn "Invalid date '$date'\n";
-            next;
-        }
-        my $z = Zodiac::Tiny::zodiac_of($date);
-        push @$res, @$dates > 1 ? [$date, $z] : $z;
+
+        # when coerced to float(epoch)
+        #my @lt = localtime($date);
+        #my $ymd = sprintf("%04d-%02d-%02d", $lt[5]+1900, $lt[4]+1, $lt[3]);
+
+        # when coerced to DateTime
+        my $ymd = $date->ymd;
+
+        my $z = Zodiac::Tiny::zodiac_of($ymd);
+        push @$res, @$dates > 1 ? [$ymd, $z] : $z;
     }
     $res = $res->[0] if @$res == 1;
     $res;
@@ -71,9 +79,7 @@ $SPEC{chinese_zodiac_of} = {
         dates => {
             summary => 'Dates',
             'x.name.is_plural' => 1,
-            #schema => ['array*', of=>'date*', min_len=>1],
-            schema => ['array*', of=>'str*', min_len=>1],
-            #'x.perl.coerce_to' => 'int(epoch)',
+            schema => $sch_array_of_dates,
             req => 1,
             pos => 0,
             greedy => 1,
@@ -102,13 +108,17 @@ sub chinese_zodiac_of {
 
     my $res = [];
     for my $date (@$dates) {
-        unless ($date =~ /\A\d\d\d\d-\d\d-\d\d\z/) {
-            warn "Invalid date '$date'\n";
-            next;
-        }
-        my $czres = Zodiac::Chinese::Table::chinese_zodiac($date);
+
+        # when coerced to float(epoch)
+        #my @lt = localtime($date);
+        #my $ymd = sprintf("%04d-%02d-%02d", $lt[5]+1900, $lt[4]+1, $lt[3]);
+
+        # when coerced to DateTime
+        my $ymd = $date->ymd;
+
+        my $czres = Zodiac::Chinese::Table::chinese_zodiac($ymd);
         my $z = $czres ? "$czres->[7] ($czres->[3])" : undef;
-        push @$res, @$dates > 1 ? [$date, $z] : $z;
+        push @$res, @$dates > 1 ? [$ymd, $z] : $z;
     }
     $res = $res->[0] if @$res == 1;
     $res;
@@ -129,7 +139,7 @@ App::ZodiacUtils - CLI utilities related to zodiac
 
 =head1 VERSION
 
-This document describes version 0.08 of App::ZodiacUtils (from Perl distribution App-ZodiacUtils), released on 2016-01-18.
+This document describes version 0.09 of App::ZodiacUtils (from Perl distribution App-ZodiacUtils), released on 2016-06-02.
 
 =head1 DESCRIPTION
 
@@ -156,11 +166,11 @@ Examples:
 
 =item * Example #1:
 
- chinese_zodiac_of( dates => ["1980-02-17"]); # -> "monkey (metal)"
+ chinese_zodiac_of(dates => ["1980-02-17"]); # -> "monkey (metal)"
 
 =item * Multiple dates:
 
- chinese_zodiac_of( dates => ["2015-12-17", "2016-12-17"]);
+ chinese_zodiac_of(dates => ["2015-12-17", "2016-12-17"]);
 
 Result:
 
@@ -171,13 +181,13 @@ Result:
 
 =back
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<dates>* => I<array[str]>
+=item * B<dates>* => I<array[date]>
 
 Dates.
 
@@ -196,11 +206,11 @@ Examples:
 
 =item * Example #1:
 
- zodiac_of( dates => ["2015-06-15"]); # -> "gemini"
+ zodiac_of(dates => ["2015-06-15"]); # -> "gemini"
 
 =item * Multiple dates:
 
- zodiac_of( dates => ["2015-12-17", "2015-12-29"]);
+ zodiac_of(dates => ["2015-12-17", "2015-12-29"]);
 
 Result:
 
@@ -211,13 +221,13 @@ differentiate which zodiac belongs to which date.
 
 =back
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<dates>* => I<array[str]>
+=item * B<dates>* => I<array[date]>
 
 Dates.
 
